@@ -106,12 +106,12 @@ showInfinite0 =
    (\t -> t==t) . take 1000000 . show .
    const (Chunky.fromChunks $ iterate (2-) (1::NonNegW.Integer))
 
-showInfinite1 :: (NonNeg.C a, Num a) => a -> Bool
+showInfinite1 :: (NonNeg.C a, Num a, Show a) => a -> Bool
 showInfinite1 =
    (\t -> t==t) . take 10000 . show .
    (\n -> Chunky.fromChunks $ iterate (2-) (1+0*n))
 
-showInfinite2 :: (NonNeg.C a, Num a) => a -> Bool
+showInfinite2 :: (NonNeg.C a, Num a, Show a) => a -> Bool
 showInfinite2 =
    (\t -> t==t) . take 10000 . show . infinity
 
