@@ -21,7 +21,7 @@ import Control.Monad (liftM, liftM2)
 import Data.Tuple.HT (mapSnd, )
 
 import qualified Data.Monoid as Mn
-import Test.QuickCheck (Arbitrary(arbitrary))
+import Test.QuickCheck (Arbitrary(arbitrary, shrink))
 
 {- |
 A chunky non-negative number is a list of non-negative numbers.
@@ -199,6 +199,7 @@ instance Mn.Monoid (T a) where
 
 instance (NonNeg.C a, Arbitrary a) => Arbitrary (T a) where
    arbitrary = liftM Cons arbitrary
+   shrink (Cons xs) = map Cons $ shrink xs
 
 
 {- * Functions that may break invariants -}
