@@ -18,7 +18,7 @@ import qualified Numeric.NonNegative.Class as NonNeg
 import Data.Monoid (Monoid, )
 import qualified Data.Monoid as Monoid
 
-import Test.QuickCheck (Arbitrary(arbitrary))
+import Test.QuickCheck (Arbitrary(arbitrary, shrink))
 import Data.Tuple.HT (mapPair, mapSnd, )
 import Control.Monad (liftM)
 
@@ -180,6 +180,7 @@ instance (Ord a, Floating a) => Floating (T a) where
 
 instance (Num a, Arbitrary a) => Arbitrary (T a) where
    arbitrary = liftM (Cons . abs) arbitrary
+   shrink (Cons xs) = map (Cons . abs) $ shrink xs
 
 
 type Int      = T P.Int
